package com.upay.sdk.icc;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson15.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.icc.v_3.builder.ApiOrderBuilder;
import com.upay.sdk.icc.v_3.entity.BillInfo;
import com.upay.sdk.icc.v_3.entity.ShipInfo;
import com.upay.sdk.icc.v_3.executer.ApiOrderExecuter;

/**
 * 令牌支付
 * @author w
 *
 */
public class ApiTokenPayOrderServlet extends HttpServlet{
	
	 static final Logger LOGGER = LoggerFactory.getLogger(ApiTokenPayOrderServlet.class);
	 
	    @Override
	    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
	        doPost(req, resp);
	    }

	    @Override
	    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
	        final String agent = req.getHeader("User-agent");//判断客户端
	        LOGGER.info("ApiTokenPayOrderServlet agent:"+agent);

	        String partnerId = req.getParameter("partnerId");
	        String projectId = req.getParameter("projectId");
	        String merchantId = req.getParameter("merchantId");
	        String requestId = req.getParameter("requestId");
	        String orderAmount = req.getParameter("orderAmount");
	        String orderCurrency = req.getParameter("orderCurrency");
	        String notifyUrl = req.getParameter("notifyUrl");
	        String remark = req.getParameter("remark");
	        String clientIp = req.getParameter("clientIp");
	        String terminalNo = req.getParameter("terminalNo");
	        String paymentData = req.getParameter("paymentData");

	        LOGGER.info("builder START...");
	        ApiOrderBuilder builder = new ApiOrderBuilder(merchantId);
	        builder.setRequestId(requestId)
            .setOrderAmount(orderAmount)
            .setOrderCurrency(orderCurrency)
            .setNotifyUrl(notifyUrl)
            .setRemark(remark)
            .setOrdip(clientIp)
            .setTerminalNo(terminalNo)
            .setPaymentData(paymentData)
            .setProjectId(projectId)
            .setPartnerId(partnerId);


	        String orderType = req.getParameter("orderType");
	        if("RISK_SHIP".equals(orderType)){
	            builder.setShipInfo(buildShip(req));
	        }
	        if("RISK_BILL".equals(orderType)){
	            builder.setBillInfo(buildBill(req));
	        }
	        if("RISK_SHIP_BILL".equals(orderType)){
	            builder.setShipInfo(buildShip(req));
	            builder.setBillInfo(buildBill(req));
	        }

	        final PrintWriter out = resp.getWriter();
	        try{
	            ApiOrderExecuter executer = new ApiOrderExecuter();
	            executer.tokenPayOrder(builder, new ResultListenerAdpater() {
	                /**
	                 * 提交成功，不代表支付成功
	                 */
	                @Override
	                public void success(JSONObject jsonObject) {
	                    LOGGER.debug("success jsonObject:[" + jsonObject + "]");
	                    req.getSession().setAttribute("json",jsonObject.toJSONString());
	                    out.println("提交成功</br>");
	                    out.println(jsonObject);
	                }

	                @Override
	                public void redirect(JSONObject jsonObject, String redirectUrl) throws IOException {
	                    resp.sendRedirect(redirectUrl);
	                    LOGGER.debug("redirectUrl:[" + redirectUrl + "]");
	                }
	            });
	        }
	        catch(ResponseException e){
	            out.println("响应异常</br>");
	            out.println(e.toString());
	        }
	        catch(HmacVerifyException e){
	            out.println("签名验证异常</br>");
	            out.println(e.toString());
	        }
	        catch(RequestException e){
	            out.println("请求异常</br>");
	            out.println(e.toString());
	        }
	        catch(UnknownException e){
	            out.println("未知异常</br>");
	            out.println(e.toString());
	        }
	    }

	    private  ShipInfo  buildShip(HttpServletRequest request){
	        ShipInfo shipInfo = new  ShipInfo();
	        shipInfo.setShipCountry(request.getParameter("shipCountry"));
	        shipInfo.setShipState(request.getParameter("shipState"));
	        shipInfo.setShipCity(request.getParameter("shipCity"));
	        shipInfo.setShipStreet(request.getParameter("shipStreet"));
	        shipInfo.setShipEmail(request.getParameter("shipEmail"));
	        shipInfo.setShipPost(request.getParameter("shipPost"));
	        shipInfo.setShipPhone(request.getParameter("shipPhone"));
	        return shipInfo;
	    }

	    private BillInfo buildBill(HttpServletRequest request){
	        BillInfo billInfo = new  BillInfo();
	        billInfo.setBillCountry(request.getParameter("billCountry"));
	        billInfo.setBillState(request.getParameter("billState"));
	        billInfo.setBillCity(request.getParameter("billCity"));
	        billInfo.setBillStreet(request.getParameter("billStreet"));
	        billInfo.setBillEmail(request.getParameter("billEmail"));
	        billInfo.setBillPost(request.getParameter("billPost"));
	        billInfo.setBillPhone(request.getParameter("billPhone"));
	        return billInfo;
	    }

}
