package com.upay.sdk.icc;

import com.alibaba.fastjson15.JSONObject;
import com.upay.sdk.FastJsonUtils;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.icc.v_3.builder.PreauthConfirmBuilder;
import com.upay.sdk.icc.v_3.executer.ApiOrderExecuter;
import com.upay.sdk.icc.v_3.executer.PreauthConfirmExecuter;
import com.upay.sdk.icc.v_3.executer.RefundExecuter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

public class RefundNotifyServlet   extends HttpServlet {

    final static Logger LOGGER = LoggerFactory.getLogger(RefundNotifyServlet.class);

    private static final String ENCRYPT_KEY = "encryptKey";
    private static final String MERCHANT_ID = "merchantId";



    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
        RefundExecuter executer = new RefundExecuter();

        try{
            JSONObject json = FastJsonUtils.convert(req.getInputStream());
            json.put(ENCRYPT_KEY,req.getHeader(ENCRYPT_KEY));
            json.put(MERCHANT_ID,req.getHeader(MERCHANT_ID));
            executer.bothCipherCallback(json, new ResultListenerAdpater() {
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.info("订单成功！");
                    LOGGER.info(jsonObject.toJSONString());
                }
                @Override
                public void failure(JSONObject jsonObject) {
                    LOGGER.info("订单失败！",jsonObject);
                    LOGGER.info(jsonObject.toJSONString());
                }
            });
        }
        catch(ResponseException e){
            LOGGER.info("响应异常");
            LOGGER.info(e.toString());
        }
        catch(HmacVerifyException e){
            LOGGER.info("签名验证异常");
            LOGGER.info(e.toString());
        }
        catch(UnknownException e){
            LOGGER.info("未知异常");
            LOGGER.info(e.toString());
        }

        LOGGER.info("ICC order notify success...");
        PrintWriter out = resp.getWriter();
        out.print("SUCCESS");
    }
}
